Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3025)

Unified Diff: chrome/browser/ui/webui/ntp/new_tab_ui_uitest.cc

Issue 7064052: Revert 88142 to fix sync_integration_tests offline. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 9 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/ntp/new_tab_ui_uitest.cc
===================================================================
--- chrome/browser/ui/webui/ntp/new_tab_ui_uitest.cc (revision 88158)
+++ chrome/browser/ui/webui/ntp/new_tab_ui_uitest.cc (working copy)
@@ -82,9 +82,9 @@
EXPECT_EQ(L"user@gmail.com", displayed_username);
}
// Loads chrome://hang/ into two NTP tabs, ensuring we don't crash.
// See http://crbug.com/59859.
-TEST_F(NewTabUITest, ChromeHangInNTP) {
+TEST_F(NewTabUITest, AboutHangInNTP) {
scoped_refptr<BrowserProxy> window(automation()->GetBrowserWindow(0));
ASSERT_TRUE(window.get());
@@ -93,15 +93,15 @@
scoped_refptr<TabProxy> tab = window->GetActiveTab();
ASSERT_TRUE(tab.get());
- // Navigate to chrome://hang/ to stall the process.
- ASSERT_TRUE(tab->NavigateToURLAsync(GURL(chrome::kChromeUIHangURL)));
+ // Navigate to about:hang to stall the process.
+ ASSERT_TRUE(tab->NavigateToURLAsync(GURL(chrome::kAboutHangURL)));
- // Visit chrome://hang/ again in another NTP. Don't bother waiting for the
+ // Visit about:hang again in another NTP. Don't bother waiting for the
// NTP to load, because it's hung.
ASSERT_TRUE(window->RunCommandAsync(IDC_NEW_TAB));
scoped_refptr<TabProxy> tab2 = window->GetActiveTab();
ASSERT_TRUE(tab2.get());
- ASSERT_TRUE(tab2->NavigateToURLAsync(GURL(chrome::kChromeUIHangURL)));
+ ASSERT_TRUE(tab2->NavigateToURLAsync(GURL(chrome::kAboutHangURL)));
}
// Allows testing NTP in process-per-tab mode.
@@ -128,8 +128,8 @@
scoped_refptr<TabProxy> tab = window->GetActiveTab();
ASSERT_TRUE(tab.get());
- // Navigate to chrome://hang/ to stall the process.
- ASSERT_TRUE(tab->NavigateToURLAsync(GURL(chrome::kChromeUIHangURL)));
+ // Navigate to about:hang to stall the process.
+ ASSERT_TRUE(tab->NavigateToURLAsync(GURL(chrome::kAboutHangURL)));
// Visit a normal URL in another NTP that hasn't committed.
ASSERT_TRUE(window->RunCommandAsync(IDC_NEW_TAB));
« no previous file with comments | « chrome/browser/ui/webui/chrome_web_ui_factory.cc ('k') | chrome/browser/ui/webui/options/about_page_handler.cc » ('j') | no next file with comments »
@@ -82,9 +82,9 @@
EXPECT_EQ(L"user@gmail.com", displayed_username);
}
-// Loads chrome://hang/ into two NTP tabs, ensuring we don't crash.
+// Loads about:hang into two NTP tabs, ensuring we don't crash.
// See http://crbug.com/59859.

Powered by Google App Engine
This is Rietveld 408576698